/*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

	Copyright (c) Non, Inc. 1997 -- All Rights Reserved

PROJECT:	JavaWorld
MODULE:		Web Stuff
FILE:		Happy.java

AUTHOR:		John D. Mitchell, Oct  6, 1997

REVISION HISTORY:
	Name	Date		Description
	----	----		-----------
	JDM	97.10.06   	Initial version.

DESCRIPTION:

	This file shows how to POST to a web-server servlet which will give
	us back a code that we can then use with showDocument() to have the
	server generated appear in a browser page.

INSTALLATION:

	Place the happy2.html file where you like.

	Compile this applet.

	Place the applet .class file in a directory below the location of
	the happy2.html file called net/non/applets/ (or you can nuke the
	package line from the code and put it in the same directory as the
	.html file :-).


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/


package net.non.applets;


// Standard Java core packages:

import java.awt.*;
import java.applet.*;
import java.io.*;
import java.util.*;
import java.net.*;


public class Happy2 extends Applet
    {
    private TextArea textArea = new TextArea (10, 70);

    public void init ()
	{
	try
	    {
	    URL			url;
	    URLConnection	urlConn;
	    DataOutputStream	printout;
	    DataInputStream	input;

	    // URL of CGI-Bin script.
	    // The servlet url string is a hack point at the root of server
	    // the applet was loaded from.
	    // Note that if you try running this from the appletviewer,
	    // you will *NOT* see the resulting document since it doesn't
	    // implement showDocument() and so the temporary files won't
	    // get deleted either. :-)
	    url = new URL ("http://" +
			   ((getCodeBase()).getHost()).toString() +
			   "/poster");

	    // URL connection channel.
	    urlConn = url.openConnection();

	    // Let the run-time system (RTS) know that we want input.
	    urlConn.setDoInput (true);

	    // Let the RTS know that we want to do output.
	    urlConn.setDoOutput (true);

	    // No caching, we want the real thing.
	    urlConn.setUseCaches (false);

	    // Specify the content type.
	    urlConn.setRequestProperty
		("Content-Type", "application/x-www-form-urlencoded");

	    // Get around any basic authentication checks.
	    // Note that you'll need to provide the base64Encode()
	    // method.
//	    urlConn.setRequestProperty
//		( "Authorization",
//		  "Basic " + base64Encode ("buford:OldParanoid") );

	    // Send POST output.
	    printout = new DataOutputStream (urlConn.getOutputStream ());

	    String content =
		"name=" + URLEncoder.encode ("Buford Early") +
		"&email=" + URLEncoder.encode ("buford@known-space.com") +
		"\n&name=" + URLEncoder.encode ("Bob Sugar") +
		"&email=" + URLEncoder.encode ("sugar@pafmb.com");
	    
	    printout.writeBytes (content);
	    printout.flush ();
	    printout.close ();

	    // Get response data.
	    input = new DataInputStream (urlConn.getInputStream ());

	    String str = null;
	    String firstLine = null;
	    while (null != ((str = input.readLine())))
		{
		// The first line should contain either "nil" (if there was
		// any sort of error) or a string that we should give back
		// to the servlet via a GET query parameter.
		if (null == firstLine)
		    firstLine = str;

		System.out.println (str);
		textArea.appendText (str + "\n");
		}

	    input.close ();

	    // Display response.
	    add ("Center", textArea);

	    // Now, get and display the server generated file in a nice,
	    // new browser window.
	    if (null != firstLine)
		{
		// Note that the server will have generated an error
		// message in the response, so we don't have to do anything
		// special here. :-)
		url = new URL ("http://" +
			       ((getCodeBase()).getHost()).toString() +
			       "/poster?" + firstLine);
		(getAppletContext()).showDocument (url, "_blank");
		}
	    }
	catch (MalformedURLException me)
	    {
	    me.printStackTrace();
	    }
	catch (IOException ioe)
	    {
	    ioe.printStackTrace();
	    }
	}	// End of method init().
    }		// End of class Happy.
